﻿using System;
using System.IO;
using System.Reflection;

class PLPlotEnv
{
    const string ManagedDllFileName = @"PLplotNet.dll";
    public static void SetEnv()
    {
        do
        {
            if (File.Exists(@".\plplot\plplot.dll") == true)
            {
                break;
            }

            if (File.Exists(ManagedDllFileName) == false)
            {
                break;
            }

            Version ver = AssemblyName.GetAssemblyName(ManagedDllFileName).Version;
            string versionText = $"{ver.Major}.{ver.Minor}.{ver.Build}";

            string path = Environment.ExpandEnvironmentVariables($@"%USERPROFILE%\.nuget\packages\plplot\{versionText}\runtimes\win-x64\native");
            if (Directory.Exists(path) == false)
            {
                break;
            }

            string targetPath = Path.GetDirectoryName(typeof(PLPlotEnv).Assembly.Location);
            targetPath = Path.Combine(targetPath, "plplot");
            DirectoryCopy(path, targetPath, true);

        } while (false);

        CopyPLplotNetFile();

        // Environment.SetEnvironmentVariable("PLPLOT_LIB", ...);
    }

    private static void CopyPLplotNetFile()
    {
        if (File.Exists(ManagedDllFileName) == false)
        {
            return;
        }

        if (File.Exists($@".\plplot\{ManagedDllFileName}") == false)
        {
            File.Copy(ManagedDllFileName, $@".\plplot\{ManagedDllFileName}");
        }

        File.Delete(ManagedDllFileName);
    }

    // https://docs.microsoft.com/ko-kr/dotnet/standard/io/how-to-copy-directories
    private static void DirectoryCopy(string sourceDirName, string destDirName, bool copySubDirs)
    {
        // Get the subdirectories for the specified directory.
        DirectoryInfo dir = new DirectoryInfo(sourceDirName);

        if (!dir.Exists)
        {
            throw new DirectoryNotFoundException(
                "Source directory does not exist or could not be found: "
                + sourceDirName);
        }

        DirectoryInfo[] dirs = dir.GetDirectories();
        // If the destination directory doesn't exist, create it.
        if (!Directory.Exists(destDirName))
        {
            Directory.CreateDirectory(destDirName);
        }

        // Get the files in the directory and copy them to the new location.
        FileInfo[] files = dir.GetFiles();
        foreach (FileInfo file in files)
        {
            string temppath = Path.Combine(destDirName, file.Name);
            file.CopyTo(temppath, false);
        }

        // If copying subdirectories, copy them and their contents to new location.
        if (copySubDirs)
        {
            foreach (DirectoryInfo subdir in dirs)
            {
                string temppath = Path.Combine(destDirName, subdir.Name);
                DirectoryCopy(subdir.FullName, temppath, copySubDirs);
            }
        }
    }
}
