﻿using PLplot;
using System;
using System.Collections.Generic;
using System.Linq;

class Program
{
    static void Main(string[] args)
    {
        PLPlotEnv.SetEnv();

        Test();
    }

    static void Test()
    {
        Dictionary<string, List<double>> data = PythonUtils.Load<double>("click.csv");

        List<double> xData = data["x"];
        List<double> yData = data["y"];

        double xMin = xData.Min() - 10;
        double xMax = xData.Max() + 10;

        double yMin = yData.Min() - 10;
        double yMax = yData.Max() + 10;

        string chartFileName = "click.svg";
        using (var pl = new PLStream())
        {
            pl.sdev("svg");
            pl.sfnam(chartFileName);
            pl.spal0("cmap0_alternate.pal");
            pl.init();

            pl.env(xMin, xMax, yMin, yMax, AxesScale.Independent, AxisBox.BoxTicksLabelsAxes);

            // Set scaling for mail title text 125% size of default
            // pl.schr(0, 1.25);

            // The main title
            pl.lab("X", "Y", "Click");

            //This code is the symbol to paint
            // http://personalpages.to.infn.it/~zaninett/libri/hershey.html
            char code = Symbol.Bullet; // == 17;

            // plot using different colors
            // see http://plplot.sourceforge.net/examples.php?demo=02 for palette indices
            //pl.col0(9); //Light Green
            //pl.col0(4); //Red
            pl.col0(2); // Blue

            pl.poin(xData.ToArray(), yData.ToArray(), code);

            // end page (writes output to disk)
            pl.eop();

            // output version of PLplot
            pl.gver(out var verText);
        }
    }

}
